<?php
// $Id$

/**
 * @file
 * OM Maximenu Admin Utilities
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
define('OM_MAXIMENU_PATH', drupal_get_path('module', 'om_maximenu')); 


/**
 * Implementation of hook_init().
 *
 */
function om_maximenu_init() {
  global $_om_maximenu_variable;
  global $_om_maximenu_block_classes;  
  
  drupal_add_css(OM_MAXIMENU_PATH . '/css/om_maximenu.css');
  drupal_add_js(OM_MAXIMENU_PATH . '/js/om_maximenu.js'); 
  
  // add om tools custom block classes    
  if (module_exists('om_tools')) {

    $om_tools_values = variable_get('om_tools', '');
    $om_blocks = isset($om_tools_values['block']) ? $om_tools_values['block']: array();
    
    if (!empty($om_blocks) && ($om_blocks['block_classes_switch'] == 1)) {
      $_om_maximenu_block_classes = array();
      foreach ($om_blocks as $block_key => $block_class) {
        $block  = explode('___', $block_key);
        if (isset($block[1])) { // filters switch/reset        
          $module = $block[1];
          $delta  = $block[2];
          $_om_maximenu_block_classes[$module][$delta] = $block_class;
        }
      }
    }
  }

  // all menus settings
  $_om_maximenu_variable  = variable_get('om_maximenu', array());

  $maximenu = $_om_maximenu_variable;
  
  if (!empty($maximenu)) {
    foreach ($maximenu as $menu_key => $menu_content) {
      $visibility_values = isset($menu_content['menu_visibility']) ? $menu_content['menu_visibility']: array('visibility' => 0, 'pages' => '');
      $visibility = om_maximenu_menu_visibility($visibility_values);
      if ($visibility) {      
        $skin          = $menu_content['skin'];
        $fade          = $menu_content['fade']; 
        $animated_bg   = isset($menu_content['animated_bg']) ? 1: 0; 
        $dock          = isset($menu_content['float_options']['dock']) ? 1: 0;
        $maximenu_name = om_string_name($menu_content['title']); 

        // add css per OM Maximenu       
        drupal_add_css(OM_MAXIMENU_PATH . '/skin/' . $skin . '/' . $skin . '.css');
      
        // add js per OM Maximenu
        if ($fade) om_maximenu_hover_js($fade, 'om-maximenu-' . $maximenu_name); 
      
        // jquery animated bg effect
        if ($animated_bg) om_maximenu_bg_slider($maximenu_name); 
      
        // jquery fisheye dock effect 
        if ($dock) om_maximenu_dock($dock, $maximenu_name);
      }
    }
  }
}


/**
 * Load all OM Maximenu blocks
 * 
 * This will process all created OM Maximenu blocks
 *
 */
function om_maximenu_block_load($maximenu_delta = '') {
  global $_om_maximenu_variable;
  $maximenu = $_om_maximenu_variable;
    
  $maximenu_delta = explode('-', $maximenu_delta);
  // ex. $maximenu_delta = 'om-maximenu-1';
  $delta = $maximenu_delta[2];
    
  $out = array();
  // om delta always starts with 1
  if (isset($maximenu[$delta]) && ($delta != 0)) {
    if (!empty($maximenu) && ($maximenu[$delta]['output'] == 'block')) {
      $visibility_values = isset($maximenu[$delta]['menu_visibility']) ? $maximenu[$delta]['menu_visibility']: array('visibility' => 0, 'pages' => '');
      $visibility = om_maximenu_menu_visibility($visibility_values);
      if ($visibility) {  
        $out['title']   = check_plain($maximenu[$delta]['title']);
        $out['content'] = om_maximenu_links_render($maximenu[$delta]);
      }
    }
  }
  return $out;  
}


/**
 * Load all OM Maximenu blocks
 * 
 * This will process the main menu and floating blocks
 *
 */
function om_maximenu_load() {
  global $_om_maximenu_variable;
  $maximenu = $_om_maximenu_variable;

  $out = array();
  if (!empty($maximenu)) {
    foreach ($maximenu as $menu_key => $menu_content) {
      $visibility_values = isset($menu_content['menu_visibility']) ? $menu_content['menu_visibility']: array('visibility' => 0, 'pages' => '');
      $visibility = om_maximenu_menu_visibility($visibility_values);
      if (($menu_content['output'] != 'block') && $visibility) {  
        $out[$menu_key]['title']   = $menu_content['title'];
        $out[$menu_key]['output']  = $menu_content['output'];
        $out[$menu_key]['content'] = om_maximenu_links_render($maximenu[$menu_key]);    
      }
    }
  }
  return $out;  
}


/**
 * OM Maximenu links rendering engine
 *
 */
function om_maximenu_links_render($links = array()) {
  // immediately returns nothing if no links
  if (!isset($links['links'])) return NULL;
    
  // menu name
  $maximenu_name = om_string_name($links['title']); 
  
  $out = '<ul id="om-menu-' . $maximenu_name . '" class="om-menu">';  
  
  // sort by weight
  usort($links['links'], 'om_sort_by_weight'); 
  
  // first, last classes  
  $count = 0;
  $total = count($links['links']);
    
  foreach ($links['links'] as $key => $content) {
  
    // user roles and permissions
    $permission = om_maximenu_link_visible($content['roles']);
    
    if (!empty($permission)) {    
      $count++;

      // php on title
      if (isset($content['php_option']) && ($content['php_option'] == 1)) {
        ob_start();
        $content['link_title'] = eval($content['link_title']);
        //$output = ob_get_contents();
        ob_end_clean(); 
      }
        
      // span id
      $span_id = (!empty($content['id'])) ? 'id="' . om_string_name($content['id']) . '"': '';        

      // span title
      $span_title = (!empty($content['description']) && ($content['description_option'] == 'hover')) ? 'title="' . check_plain($content['description']) . '"': ''; 
    
      // link content      
      $link_option = om_maximenu_link_option($content);
      
      // a link attributes
      $attributes = om_maximenu_link_attrib($content);
            
      $out .= '<li id="om-leaf-' . $key . '" class="' . om_maximenu_link_classes($content, $permission, $count, $total) . '">';    
      if (!empty($content['path'])) {
        // Drupal doesn't accept # as valid path
        //$out .= l($content['link_title'], $content['path'], array('attributes' => $attributes));
        $path = ($content['path'] == '<front>') ? '': $content['path'];
        $out .= '<a ' . drupal_attributes($attributes) . ' href="' . base_path() . $path . '">' . $link_option . '</a>';
      }
      else {
        // useful when you just want a button for getting the content to show and not actually linking to anything
        $out .= '<span ' . $span_id . ' class="' . $attributes['class'] . '" ' . $span_title . '>' . $link_option . '</span>';
      }
      
      // finally, getting the content
      $out .= om_maximenu_content_render($content['content']); 
         
      $out .= '</li>';
    } // permission closing
  } // foreach closing
  $out .= '</ul>';  
   
  // for animated sliding background
  $out .= isset($links['animated_bg']) ? '<div id="om-maximenu-slider-' . $maximenu_name . '" class="om-maximenu-slider"></div>': '';   
   
  // access on editing
  if (user_access('administer OM Maximenu')) $out .= '<div class="om-maximenu-edit"><a href="' . base_path() . 'admin/settings/om-maximenu?destination=' . $_GET['q'] . '">Maxedit</a></div>';    
  
  return om_maximenu_float_wrapper($links, $out);
}


/**
 * OM Maximenu content rendering engine
 *
 */
function om_maximenu_content_render($content = '') {
  global $_om_maximenu_block_classes;
    
  $block_classes = !empty($_om_maximenu_block_classes) ? $_om_maximenu_block_classes: array();  
  
  if (!empty($content)) {
    // enclose the content with divs for efficient image border theming
    $out = '<div class="om-maximenu-content om-maximenu-content-nofade closed">';
    $out .= '<div class="om-maximenu-top"><div class="om-maximenu-top-left"></div><div class="om-maximenu-top-right"></div></div>';
    $out .= '<div class="om-maximenu-middle"><div class="om-maximenu-middle-left"><div class="om-maximenu-middle-right">';      
    $count = 0;
    usort($content, 'om_sort_by_weight'); 
    $total = count($content); 

    foreach ($content as $key => $prop) {
        $count++;
        
        $module      = $prop['module'];
        $delta       = $prop['delta'];
        $title       = trim($prop['title']); // allows markups
        $path        = ($prop['title_path'] == '<front>') ? '': $prop['title_path'];
        $block_title = (!empty($prop['title_path'])) ? '<a href="' . base_path() . $path .'" title="' . $title . '">' . $title . '</a>': $title;      
        $block       = module_invoke($module, 'block', 'view', $delta); 
        $classes = ($count == 1) ? ' first': '';
        if ($count == $total) $classes .= ' last'; 
        $classes .=  isset($block_classes[$module][$delta]) ? ' ' . $block_classes[$module][$delta]: ''; 
               
        $out .= '<div class="block block-' . $module . ' block-' . $module . '-id-' . $delta . $classes . '">';            
        $out .= ($title != '<none>') ? '<h3 class="title">' . $block_title . '</h3>': ''; 
        $out .= '<div class="content">' . $block['content'] . '</div>'; 
        if (user_access('administer blocks')) $out .= om_maximenu_block_edit($module, $delta, $title);
        $out .= '</div>';            
    }

    $out .= '<div class="clearfix"></div></div></div></div>';      
    $out .= '<div class="om-maximenu-bottom"><div class="om-maximenu-bottom-left"></div><div class="om-maximenu-bottom-right"></div></div>';    
    $out .= '<div class="om-maximenu-arrow"></div>';  
    $out .= '<div class="om-maximenu-open"><input type="checkbox" value="" />' . t('Stay') . '</div>';          
    $out .= '</div>'; 
    return $out;
  } 
}

/**
 * Sorting by weight
 *
 */
function om_sort_by_weight($a, $b) {
  return $a['weight'] - $b['weight'];
}

/**
 * Converts string either to a title or a class
 *
 */
function om_string_name($string = NULL, $class = TRUE) {
  // for the purpose of just showing the classes and title
  // any tags are stripped off
  $string = trim(strip_tags($string));
  // if there are slashes
  $string = stripslashes($string);  
  // ignores characters other than a-z, A-Z, 0-9
  $string_class = preg_replace('/[^a-zA-Z0-9-]+/', ' ', $string);  
  // allows apostrophe
  $string_title = preg_replace('/[^a-zA-Z0-9-\']+/', ' ', $string); 
  // space and underscore are converted depending on use
  $pattern = '/[ _]+/';     
  $string = ($class == FALSE) ? ucwords(preg_replace($pattern, ' ', $string_title)): strtolower(preg_replace($pattern, '-', $string_class));
  // if result is none for non-class
  if (empty($string) && $class == FALSE) $string = 'Script Link';
  
  return $string;
}


/**
 * Link Options
 *
 */
function om_maximenu_link_option($content = array()) {

  // img hover replacement class
  $icon_option = (isset($content['icon_option']) && ($content['icon_option'] == 1)) ? 'class="om-hover"': '';
      
  // title, icon options
  $link_title        = $content['link_title'];
  $link_title_option = $content['link_title_option'];
  $link_icon         = !empty($content['path_icon']) ? '<img ' . $icon_option . ' src="' . base_path() . $content['path_icon'] . '" alt="' . om_string_name($link_title, FALSE) . '" />': '';
      
  if ($link_title_option == 'title_icon') {
    $link_option = $link_icon . ' ' . $link_title;
  }
  elseif ($link_title_option == 'icon') {
    $link_option = $link_icon;
  }
  else {
    $link_option = $link_title;
  }
  
  // description as subtitle
  $link_subtitle = (!empty($content['description']) && ($content['description_option'] != 'hover')) ? '<span class="om-subtitle">' . check_plain($content['description']) . '</span>': ''; 
        
  return $link_option . $link_subtitle;
}
  
      
/**
 * Link attribute
 *
 */
function om_maximenu_link_attrib($content = array()) {
  
  // initialize link attributes and classes
  $attributes = array();
      
  // id link attributes
  if (!empty($content['id'])) $attributes['id'] = om_string_name($content['id']);
  
  // user added custom classes
  $custom_classes = '';
  $classes = explode(' ', $content['class']);
  foreach ($classes as $ckey => $class) {
    $custom_classes .= ' ' . om_string_name($class);
  }
  
  // class link attributes      
  $attributes['class'] = 'om-link' . $custom_classes . ' link-' . om_string_name($content['link_title']);
  
  // active class       
  if ($_GET['q'] == $content['path']) $attributes['class'] .= ' active'; 
  
  if ((empty($content['path']) || ($content['path'] == '<front>')) && drupal_is_front_page()) $attributes['class'] .= ' active';   
  
  // link description options
  if (!empty($content['description']) && ($content['description_option'] == 'hover')) $attributes['title'] = check_plain($content['description']); 

  // relationship
  if (!empty($content['rel'])) $attributes['rel'] = $content['rel'];

  // target
  if (!empty($content['target']) && ($content['target'] != '_self')) $attributes['target'] = $content['target'];

  return $attributes;
} 


/**
 * Classes aggregator
 *
 */
function om_maximenu_classes($links = array()) {
  $classes = array();
  
  // bubble, simple, no_style  
  $classes[] = $links['skin'];
  
  // block, float, main_menu  
  $classes[] = $links['output'];
  
  if ($links['output'] == 'block') {
    // up, right, down, left
    $classes[] = isset($links['block_options']['direction']) ? $links['block_options']['direction']: 'block-down';   
  }
  elseif ($links['output'] == 'float') {
    // left, middle, right
    $classes[] = isset($links['float_options']['orientation']) ? $links['float_options']['orientation']: 'horizontal';       
    $classes[] = isset($links['float_options']['stacking']) ? $links['float_options']['stacking']: 'row';   
    $classes[] = isset($links['float_options']['x_origin']) ? $links['float_options']['x_origin']: 'left';   
    $classes[] = isset($links['float_options']['y_origin']) ? $links['float_options']['y_origin']: 'bottom';   
  }
  elseif ($links['output'] == 'main_menu') {
    // no class
  }   
  
  // fisheye dock class
  if (isset($links['float_options']['dock'])) $classes[] = 'dock';
  
  $out = '';
  foreach ($classes as $key => $class) {
    $out .= ' om-maximenu-' . om_string_name($class);   
  }
  return $out;
}  


/**
 * OM Maximenu inline styling
 *
 */
function om_maximenu_inline_style($links = array()) {
  $out = '';
  if ($links['output'] == 'block') {
    // do nothing now, maybe in the future
  }  
  elseif ($links['output'] == 'float') {
    // fixed/absolute
    $position    = (isset($links['float_options']['position']) && ($links['float_options']['position'] == 'absolute')) ? 'absolute': 'fixed';   
    // left/middle/right
    if (isset($links['float_options']['x_origin']) && ($links['float_options']['x_origin'] != 'middle')) {
      $x_origin    = isset($links['float_options']['x_origin']) ? $links['float_options']['x_origin']: 'left';     
      $x_value     = isset($links['float_options']['x_value']) ? $links['float_options']['x_value']: 10;
      $x_px        = ($x_value != 0) ? 'px': '';
      $x_prop      = $x_origin . ': ' . $x_value . $x_px . '; '; 
    } 
    else {
      $x_prop = ''; // jquery will determine the position
    }  
    // top/bottom
    $y_origin    = isset($links['float_options']['y_origin']) ? $links['float_options']['y_origin']: 'bottom';     
    $y_value     = isset($links['float_options']['y_value']) ? $links['float_options']['y_value']: 10; 
    $y_px        = ($y_value != 0) ? 'px': '';    
    $y_prop      = $y_origin . ': ' . $y_value . $y_px . '; ';
               
    $out = ' style="position: ' . $position . '; ' . $x_prop  . $y_prop . '" ';   
  }
  elseif ($links['output'] == 'main_menu') {
    // do nothing now, maybe in the future
  }
  
  return $out;
}


/**
 * Link classes processor
 *
 */
function om_maximenu_link_classes($content = array(), $permission = array(), $count = 0, $total = 0) {
  // initialize link classes
  $classes = array();     
                        
  // standard li classes
  if ($count == 1) $classes[] = 'first';
  if ($count == $total) $classes[] = 'last';  
      
  // link title class
  $classes[] = 'leaf-' . $content['link_title'];     

  // active class       
  if ($_GET['q'] == $content['path']) $classes[] = 'active'; 
      
  if ((empty($content['path']) || ($content['path'] == '<front>')) && drupal_is_front_page()) $classes[] = 'active';   
      
  // user role class
  if (is_array($permission)) {
    foreach ($permission as $pkey => $pval) {
      $classes[] = 'leaf-role-' . $pval; 
    }  
  }      
        
  // title, icon options
  $link_title_option = $content['link_title_option'];
  if ($link_title_option == 'title_icon') {
    $classes[] = 'om-leaf-title-icon';
  }
  elseif ($link_title_option == 'icon') {
    $classes[] = 'om-leaf-icon';
  }
  
  $out = 'om-leaf';
  foreach ($classes as $key => $class) {
    $out .= ' ' . om_string_name($class);   
  }
  return $out;
}


/**
 * Link visibility per user role
 *
 */
function om_maximenu_link_visible($roles = array()) {
  global $user;

  // user roles  
  $user_id = $user->uid;  
  $user_roles = $user->roles;  
  // user permission to view the link
  // roles
  // 1 - anonymous
  // 2 - authenticated

  $permission = array();
  $anyone = 0;
  foreach ($roles as $role => $value) {
     // check roles
     if (($value != 0) && isset($user_roles[$role])) $permission[$role] = $user_roles[$role];
     // for all roles are unchecked
     if ($value != 0) $anyone++;       
  }
  // the link will be visible if the user has permission 
  if (!empty($permission)) {
    return $permission;
  }
  elseif ($anyone == 0) { // the links is for everybody
    return 1;
  }
  elseif ($user_id == 1) { // the user is a super user
    return 1;
  }
  else {
    return 0;
  }
}      
  
/**
 * OM Maximenu get styles from /skin directory
 * - reads directory names
 */
function om_maximenu_style_get() {
  $files = array();
  $dir = OM_MAXIMENU_PATH . '/skin/';
  $folders = scandir($dir);
  $excluded_files = array('.', '..', '.cvs', '.svn', '.git');

  foreach ($folders as $key => $val) {
    if (!in_array($val, $excluded_files)) (is_dir($dir . $val)) ? $files[$val] = om_string_name($val, FALSE): '';     
  }
  return $files;
}


/**
 * Hover delay using hoverintent jquery plugin
 *
 */
function om_maximenu_hover_js($checked = 0, $menu = 'om-maximenu') {
  
  $add_js = "
    $(document).ready(function(){
      $('#" . $menu . " li.om-leaf .om-maximenu-content').removeClass('om-maximenu-content-nofade');
      //$('#" . $menu . " li.om-leaf').hover(omFadeIn,omFadeOut); //native jquery
      //$('#" . $menu . " li.om-leaf').hoverIntent(omFadeIn,omFadeOut); //jquery hoverintent
      $('#" . $menu . " li.om-leaf').hoverIntent({
        over: omFadeIn,
        timeout: 500,
        out: omFadeOut
      });
    });
    function omFadeIn(){ $('.om-maximenu-content.closed', this).fadeIn();}
    function omFadeOut(){ $('.om-maximenu-content.closed', this).fadeOut();} 
    ";
  if ($checked == 1) {
    drupal_add_js(OM_MAXIMENU_PATH . '/contrib/jquery.hoverIntent.minified.js'); 
    drupal_add_js($add_js, "inline");
  }
}


/**
 * Dock jquery plugin
 *
 */
function om_maximenu_dock($checked = 0, $menu = '') {
  
  $add_js = "
    $(document).ready(function(){
     $('#om-menu-" . $menu . " .om-link img').resizeOnApproach();
		});
    ";
  if ($checked == 1) {
    drupal_add_js(OM_MAXIMENU_PATH . '/contrib/jquery.resizeOnApproach.min.js'); 
    drupal_add_js($add_js, "inline");
  }
}

/**
 * Animated background slider
 *
 */
function om_maximenu_bg_slider($menu = NULL) {

  $add_js = "
    $(document).ready(function(){
      om_menu_slider.init('om-menu-" . $menu . "','om-maximenu-slider-" . $menu . "');
    });   
    var om_menu_slider=function(){
	  var m,e,g,s,q,i; e=[]; q=8; i=8;
	  return{
		  init:function(j,k){
			  m=document.getElementById(j); e=m.getElementsByTagName('li');
			  var i,l,w,p; i=0; l=e.length;
			  for(i;i<l;i++){
				  var c,v; c=e[i]; v=c.value; if(v==1){s=c; w=c.offsetWidth; p=c.offsetLeft}
				  c.onmouseover=function(){om_menu_slider.mo(this)}; c.onmouseout=function(){om_menu_slider.mo(s)};
		  	}
			  g=document.getElementById(k); g.style.width=w+'px'; g.style.left=p+'px';
		  },
		  mo:function(d){
			  clearInterval(m.tm);
			  var el,ew; el=parseInt(d.offsetLeft); ew=parseInt(d.offsetWidth);
			  m.tm=setInterval(function(){om_menu_slider.mv(el,ew)},i);
		  },
		  mv:function(el,ew){
			  var l,w; l=parseInt(g.offsetLeft); w=parseInt(g.offsetWidth);
			  if(l!=el||w!=ew){
				  if(l!=el){var ld,lr,li; ld=(l>el)?-1:1; lr=Math.abs(el-l); li=(lr<q)?ld*lr:ld*q; g.style.left=(l+li)+'px'}
				  if(w!=ew){var wd,wr,wi; wd=(w>ew)?-1:1; wr=Math.abs(ew-w); wi=(wr<q)?wd*wr:wd*q; g.style.width=(w+wi)+'px'}
			  }else{clearInterval(m.tm)}
      }
    };
  }();
  ";
  drupal_add_js($add_js, "inline");  
}
    

/**
 * Admin - hide/show options
 *
 */
function om_maximenu_admin_js() {
  
  $add_js = "
    $(document).ready(function(){
      $('form#om-maximenu-admin select.om-maximenu-output').change(function() {
        var parent_wrapper = $(this).parent().parent().parent().attr('id');  
        var output_value = $(this).val(); 

        if(output_value == 'block') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').show();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').hide();          
        }
        if(output_value == 'float') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').show();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').hide();
        }     
        if(output_value == 'main_menu') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').hide();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').hide();
        } 
      });

      $('form#om-maximenu-admin select.om-maximenu-x-origin').change(function() {
        var option_wrapper = $(this).parent().attr('id');  
        var x_origin_value = $(this).val(); 
        //alert(option_wrapper);
        if(x_origin_value == 'middle') {
          $('form#om-maximenu-admin #' + option_wrapper + '+fieldset.om-maximenu-non-middle-options').hide();
        }
        else {
          $('form#om-maximenu-admin #' + option_wrapper + '+fieldset.om-maximenu-non-middle-options').show();
        }     
      });     
    }); ";
  
  drupal_add_js($add_js, "inline");
}


/**
 * Float wrapper
 *
 */
function om_maximenu_float_wrapper($links = array(), $content = NULL) {
  $out = '';
  if (!empty($content)) {
    global $user;  
    $maximenu_name = om_string_name($links['title']); 
    $code     = 'om-u'. $user->uid . '-' . mt_rand();
    $link_code = isset($links['code']) ? trim($links['code']): $code;    
    $out .= '<div id="om-maximenu-' . $maximenu_name . '" class="om-maximenu' . om_maximenu_classes($links) . ' code-' . $link_code . '"' . om_maximenu_inline_style($links) . '>';      
    //$out .= '<div id="om-maximenu-' . $maximenu_name . '-outer" class="om-maximenu-wrapper-outer">';
    $out .= ($links['output'] == 'float') ? '<div id="om-maximenu-' . $maximenu_name . '-inner" class="om-maximenu-wrapper-inner">' . $content . '</div>': $content;
    //$out .= '</div>';
    $out .= '</div>';    
  }
  return $out;
}



/**
 * Block edit link
 *
 */
function om_maximenu_block_edit($module, $delta, $title = NULL) {
  $vars = array();
  // Display 'edit block' for custom blocks.
  if ($module == 'block') {
    $vars[] = l( t('edit block'), 'admin/build/block/configure/' . $module . '/' . $delta,
      array(
        'attributes' => array(
          'title' => t('Edit this block\'s content.'),
          'class' => 'block-edit',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  // Display 'configure' for other blocks.
  else {
    $vars[] = l( t('configure'), 'admin/build/block/configure/' . $module . '/' . $delta,
      array(
        'attributes' => array(
          'title' => t('Configure ' . $title),
          'class' => 'block-config',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  // Display 'edit view' for Views blocks.
  if ($module == 'views' && user_access('administer views')) {
    list($view_name, $view_block) = explode('-block', $delta);
    $vars[] = l( t('edit view'), 'admin/build/views/edit/' . $view_name,
      array(
        'attributes' => array(
          'title' => t('Edit this view.'),
          'class' => 'block-edit-view',
        ),
        'query' => drupal_get_destination(),
        'fragment' => 'views-tab-block' . $view_block,
        'html' => TRUE,
      )
    );
  }
  // Display 'edit menu' for Menu blocks.
  elseif (($module == 'menu' || ($module == 'user' && $delta == 1)) && user_access('administer menu')) {
    $menu_name = ($module == 'user') ? 'navigation' : $delta;
    $vars[] = l( t('edit menu'), 'admin/build/menu-customize/' . $menu_name,
      array(
        'attributes' => array(
          'title' => t('Edit this menu.'),
          'class' => 'block-edit-menu',
        ),
        'query' => drupal_get_destination(),
        'html' => TRUE,
      )
    );
  }
  $out = '<div class="edit-block">' . implode(' ', $vars) . '</div>';
  return $out;
}


/**
 * Menu Visibility
 *
 */
function om_maximenu_menu_visibility($menu_visibility = FALSE) {
  if ($menu_visibility['pages']) {
    if ($menu_visibility['visibility'] < 2) {
      $path = drupal_get_path_alias($_GET['q']);
        $page_match = drupal_match_path($path, $menu_visibility['pages']);
        if ($path != $_GET['q']) {
          $page_match = $page_match || drupal_match_path($_GET['q'], $menu_visibility['pages']);
        }
        $page_match = !($menu_visibility['visibility'] xor $page_match);
    }
    else {
        $page_match = drupal_eval($menu_visibility['pages']);
    }
  }
  else {
      $page_match = TRUE;
  }
  return $page_match;
}

/**
 * Block Configure Page - Get delta visiblity value form _om_maximenu_variable;
 *
 *

function om_maximenu_form_alter(&$form, $form_state, $form_id) { 
  global $_om_maximenu_variable;
  $maximenu = $_om_maximenu_variable;
  switch($form_id) {
    case 'block_admin_configure':
      $delta = explode("-",$form['delta']['#value']);
      $delta = $delta[2];
      $form['page_vis_settings']['visibility']['#default_value'] = $maximenu[$delta]['menu_visibility']['visibility'];
      $form['page_vis_settings']['pages']['#default_value'] = $maximenu[$delta]['menu_visibility']['pages'];
      $form['#submit'][] = '_om_maximenu_block_admin_configure_submit_handler';
    break;
  }
}

function _om_maximenu_block_admin_configure_submit_handler(&$form, $form_state, $form_id) {
  $delta = $form_state['values']['delta'];

  if(isset($delta)) {
    global $_om_maximenu_variable;
    $maximenu = $_om_maximenu_variable;
    $delta = explode("-", $delta);
    $delta = $delta[2];
    $maximenu[$delta]['menu_visibility']['visibility'] = $form_state['values']['visibility'];   
    $maximenu[$delta]['menu_visibility']['pages'] = $form_state['values']['pages'];
    variable_set('om_maximenu', $maximenu);
  }
}

*/
